/* (C) 2022 YiRing, Inc. */
package com.yiring.app.domain.visitor;

import com.fasterxml.jackson.annotation.JsonFormat;
import java.io.Serializable;
import java.time.LocalDateTime;
import javax.persistence.*;
import lombok.*;
import lombok.experimental.FieldDefaults;
import lombok.experimental.FieldNameConstants;
import org.hibernate.annotations.Comment;
import org.hibernate.annotations.GenericGenerator;
import org.hibernate.snowflake.SnowflakeId;

/**
 * @author tzl
 * 2022/4/19 11:41
 */
@Getter
@Setter
@ToString
@Builder
@NoArgsConstructor
@AllArgsConstructor
@FieldNameConstants
@FieldDefaults(level = AccessLevel.PRIVATE)
@Entity
@Table(name = "BS_VISITOR")
@Comment("访客信息")
public class Visitor implements Serializable {

    private static final long serialVersionUID = -7367226565168197562L;

    @Id
    @Comment("主键")
    @GeneratedValue(generator = SnowflakeId.GENERATOR)
    @GenericGenerator(name = SnowflakeId.GENERATOR, strategy = SnowflakeId.Strategy.LONG)
    Long id;

    @Comment("到访人姓名")
    String visitorName;

    @Comment("到访人电话")
    String visitorMobile;

    @Comment("到访人身份证")
    String visitorCarNum;

    @Comment("是否特殊作业")
    boolean taskType;

    @Comment("邀请人数")
    Integer numOfVisitor;

    @Comment("访客来源")
    String visitorSource;

    @Comment("标签卡")
    String labelCard;

    @Comment("标签卡状态")
    String labelCardStatus;

    @Comment("所属单位id")
    String orgId;

    @Comment("被访人id")
    String intervieweeId;

    @Comment("来访原因")
    String reason;

    @Comment("收卡时间")
    @JsonFormat(pattern = "yyyy-MM-dd HH:mm:ss")
    LocalDateTime cardRecTime;

    @Comment("预约到访时间")
    @JsonFormat(pattern = "yyyy-MM-dd HH:mm:ss")
    LocalDateTime appOfVisitTime;

    @Comment("创建时间")
    @JsonFormat(pattern = "yyyy-MM-dd HH:mm:ss")
    LocalDateTime createTime;

    @Comment("发卡时间")
    @JsonFormat(pattern = "yyyy-MM-dd HH:mm:ss")
    LocalDateTime cardSendTime;

    @Comment("备用字段")
    String reserve1;

    @Comment("备用字段")
    String reserve2;

    @Comment("备用字段")
    String reserve3;
}
