/* (C) 2022 YiRing, Inc. */
package com.yiring.auth.excel.post;

import com.fasterxml.jackson.databind.annotation.JsonSerialize;
import com.fasterxml.jackson.databind.ser.std.ToStringSerializer;
import com.github.liaochong.myexcel.core.annotation.ExcelColumn;
import com.github.liaochong.myexcel.core.annotation.ExcelModel;
import com.yiring.auth.domain.post.Post;
import java.util.List;
import java.util.stream.Collectors;
import lombok.AccessLevel;
import lombok.Builder;
import lombok.Data;
import lombok.experimental.FieldDefaults;

/**
 * 职位信息导出模型
 * @author LJ-2204
 * @date 2022/4/13
 */

@ExcelModel
@Data
@Builder
@FieldDefaults(level = AccessLevel.PRIVATE)
public class PostExcel {

    @ExcelColumn(title = "编号")
    @JsonSerialize(using = ToStringSerializer.class)
    Long id;

    @ExcelColumn(title = "职位名称")
    String name;

    @ExcelColumn(title = "职位描述")
    String describe;

    @ExcelColumn(title = "是否启用")
    @JsonSerialize(using = ToStringSerializer.class)
    Boolean enable;

    public static List<PostExcel> transforms(List<Post> posts) {
        return posts
            .stream()
            .map(post ->
                PostExcel
                    .builder()
                    .id(post.getId())
                    .name(post.getName())
                    .describe(post.getDescribe())
                    .enable(post.getEnable())
                    .build()
            )
            .collect(Collectors.toList());
    }
}
